class IndexException extends Exception {
}

class InvalidBitStringException extends Exception {

}

class BitSet {

	static final int LAENGE = 8;

	protected int[] bitfolge;

	public BitSet() {
		this.bitfolge = new int[LAENGE];
		for (int i = 0; i < LAENGE; i++) {
			this.bitfolge[i] = 0;
		}
	}

	public BitSet(String str) throws InvalidBitStringException {
		if (str.length() != LAENGE) {
			throw new InvalidBitStringException();
		}
		this.bitfolge = new int[LAENGE];
		for (int i = 0; i < LAENGE; i++) {
			if (!(str.charAt(i) == '0' || str.charAt(i) == '1')) {
				throw new InvalidBitStringException();
			}
			this.bitfolge[i] = str.charAt(i) - '0';
		}
	}

	public BitSet(BitSet menge) {
		this.bitfolge = new int[LAENGE];
		for (int i = 0; i < LAENGE; i++) {
			this.bitfolge[i] = menge.bitfolge[i];
		}
	}

	protected BitSet clone() {
		return new BitSet(this);
	}

	public String toString() {
		String bitstring = "";
		for (int i = 0; i < LAENGE; i++) {
			bitstring = bitstring + this.bitfolge[i];
		}
		return bitstring;
	}

	public boolean equals(Object obj) {
		BitSet menge = (BitSet) obj;
		for (int i = 0; i < LAENGE; i++) {
			if (this.bitfolge[i] != menge.bitfolge[i]) {
				return false;
			}
		}
		return true;
	}

	public void set(int bit) throws IndexException {
		if (bit <= 0 || bit > 8) {
			throw new IndexException();
		}
		this.bitfolge[bit - 1] = 1;
	}

	public void delete(int bit) throws IndexException {
		if (bit <= 0 || bit > 8) {
			throw new IndexException();
		}
		this.bitfolge[bit - 1] = 0;
	}

	public BitSet and(BitSet menge) {
		for (int i = 0; i < LAENGE; i++) {
			if (this.bitfolge[i] == 1 && menge.bitfolge[i] == 1) {
				this.bitfolge[i] = 1;
			} else {
				this.bitfolge[i] = 0;
			}
		}
		return this;
	}

	public BitSet or(BitSet menge) {
		for (int i = 0; i < LAENGE; i++) {
			if (this.bitfolge[i] == 1 || menge.bitfolge[i] == 1) {
				this.bitfolge[i] = 1;
			} else {
				this.bitfolge[i] = 0;
			}
		}
		return this;
	}

	public BitSet not() {
		for (int i = 0; i < LAENGE; i++) {
			this.bitfolge[i] = (this.bitfolge[i] + 1) % 2;
		}
		return this;
	}

	public static BitSet and(BitSet menge1, BitSet menge2) {
		BitSet menge3 = new BitSet(menge1);
		return menge3.and(menge2);
	}

	public static BitSet or(BitSet menge1, BitSet menge2) {
		BitSet menge3 = new BitSet(menge1);
		return menge3.or(menge2);
	}

	public static BitSet not(BitSet menge1) {
		BitSet menge2 = new BitSet(menge1);
		return menge2.not();
	}
}

public class UE21Aufgabe10 {

	public static void main(String[] args) {
		try {
			BitSet menge1 = new BitSet();
			menge1.set(1);
			menge1.set(3);
			menge1.set(8);
			BitSet menge2 = new BitSet(menge1);
			menge2.delete(3);
			menge2.not();
			System.out.println(menge1);
			System.out.println(menge2);

			menge1.and(menge2);
			System.out.println(menge1);

			BitSet menge3 = BitSet.and(menge1, menge2);
			System.out.println(menge3);

			menge1.and(menge2).or(menge3);
			System.out.println(menge1);

			if (((BitSet) menge1.clone()).equals(menge1)) {
				System.out.println("sind gleich");
			}
		} catch (IndexException exc) {
			System.out.println("Index-Fehler!");
		}
	}
}
