class NullException extends Exception {
}

class LeeresArrayException extends Exception {
}

class KeineZahlException extends Exception {
}

class NegativerExponentException extends Exception {
}

class Vorgabe {

	// liefert die kleinste Zahl des uebergebenen Arrays
	static int minimum(int[] werte) throws NullException, LeeresArrayException {
		if (werte == null) {
			throw new NullException();
		}
		if (werte.length == 0) {
			throw new LeeresArrayException();
		}
		int min = werte[0];
		for (int i = 1; i < werte.length; i++) {
			if (werte[i] < min) {
				min = werte[i];
			}
		}
		return min;
	}

	// konvertiert den uebergebenen String in einen int-Wert
	static int toInt(String str) throws NullException, KeineZahlException {
		if (str == null) {
			throw new NullException();
		}
		if (str.length() == 0) {
			throw new KeineZahlException();
		}
		int erg = 0, faktor = 1;
		for (int i = 1; i < str.length(); i++) {
			char ch = str.charAt(i);
			int ziffer = ch - '0';
			if (ziffer < 0 || ziffer > 9) {
				throw new KeineZahlException();
			}
			erg = erg * 10 + ziffer;
		}
		return faktor * erg;
	}

	// liefert die Potenz von zahl mit exp, also zahl "hoch" exp
	static int hoch(int zahl, int exp) throws NegativerExponentException {
		if (exp < 0) {
			throw new NegativerExponentException();
		}
		if (exp == 0) {
			return 1;
		} else {
			return zahl * hoch(zahl, exp - 1);
		}
	}

	// Testprogramm
	public static void main(String[] args) {
		try {
			int[] zahlen = new int[args.length];
			for (int i = 0; i < args.length; i++) {
				zahlen[i] = toInt(args[i]);
			}
			System.out.println(hoch(2, minimum(zahlen)));
		} catch (NullException exc) {
			System.out.println("Keine Argumente");
		} catch (KeineZahlException exc) {
			System.out.println("Ungueltige Argumente");
		} catch (LeeresArrayException e) {
			System.out.println("Leeres Array");
		} catch (NegativerExponentException e) {
			System.out.println("Negativer Exponent");
		}
	}

}


public class UE21Aufgabe26 {

	// Fehlerkonstanten
	public static final int NO_ERROR = 0;
	public static final int NULL_ERROR = 1;
	public static final int LEERES_ARRAY_ERROR = 2;
	public static final int KEINE_ZAHL_ERROR = 3;
	public static final int NEGATIVER_EXPONENT_ERROR = 4;

	// globale Fehlervariable
	public static int error = NO_ERROR;

	// liefert die kleinste Zahl des uebergebenen Arrays
	static int minimum(int[] werte) {
		if (werte == null) {
			error = NULL_ERROR;
			return 0;
		}
		if (werte.length == 0) {
			error = LEERES_ARRAY_ERROR;
			return 0;
		}
		int min = werte[0];
		for (int i = 1; i < werte.length; i++) {
			if (werte[i] < min) {
				min = werte[i];
			}
		}
		error = NO_ERROR;
		return min;
	}

	// konvertiert den uebergebenen String in einen int-Wert
	static int toInt(String str) {
		if (str == null) {
			error = NULL_ERROR;
			return 0;
		}
		if (str.length() == 0) {
			error = KEINE_ZAHL_ERROR;
			return 0;
		}
		int erg = 0, faktor = 1;
		for (int i = 0; i < str.length(); i++) {
			char ch = str.charAt(i);
			int ziffer = ch - '0';
			if (ziffer < 0 || ziffer > 9) {
				error = KEINE_ZAHL_ERROR;
				return 0;
			}
			erg = erg * 10 + ziffer;
		}
		error = NO_ERROR;
		return faktor * erg;
	}

	// liefert die Potenz von zahl mit exp, also zahl "hoch" exp
	static int hoch(int zahl, int exp) {
		if (exp < 0) {
			error = NEGATIVER_EXPONENT_ERROR;
			return 0;
		}
		if (exp == 0) {
			error = NO_ERROR;
			return 1;
		} else {
			error = NO_ERROR;
			return zahl * hoch(zahl, exp - 1);
		}
	}

	// Testprogramm
	static void main(String[] args) {
		int[] zahlen = new int[args.length];
		for (int i = 0; i < args.length; i++) {
			zahlen[i] = toInt(args[i]);
			if (error == NULL_ERROR) {
				System.out.println("Keine Argumente");
				return;
			}
			if (error == KEINE_ZAHL_ERROR) {
				System.out.println("Ungueltige Argumente");
				return;
			}
		}
		int min = minimum(zahlen);
		if (error == NULL_ERROR) {
			System.out.println("Keine Argumente");
			return;
		}
		if (error == LEERES_ARRAY_ERROR) {
			System.out.println("Leeres Array");
			return;
		}
		int wert = hoch(2, min);
		if (error == NEGATIVER_EXPONENT_ERROR) {
			System.out.println("Negativer Exponent");
			return;
		}
		System.out.println(wert);
	}

}
