class IsEmptyException extends Exception {
}

class IsFullException extends Exception {
}

class EStack {

	private Object[] speicher;
	private int aktIndex;

	public EStack(int maxSize) {
		this.speicher = new Object[maxSize];
		this.aktIndex = -1;
	}

	/**
	 * Legt ein Objekt auf dem Stack ab
	 * 
	 * @param wert
	 *            das auf dem Stack abzulegende Objekt
	 * @throws IsFullException
	 *             wird geworfen, wenn der Stack voll ist
	 */
	public final void push(Object wert) throws IsFullException {
		if (this.aktIndex == this.speicher.length - 1) {
			throw new IsFullException();
		}
		this.speicher[++this.aktIndex] = wert;
	}

	/**
	 * liefert das Objekt, dass sich oben auf dem Stack befindet, und entfernt
	 * es vom Stack
	 * 
	 * @return das Objekt, dass sich oben auf dem Stack befindet
	 * @throws IsEmptyException
	 *             wird geworfen, wenn der Stack leer ist
	 */
	public final Object pop() throws IsEmptyException {
		if (this.aktIndex == -1) {
			throw new IsEmptyException();
		}
		return this.speicher[this.aktIndex--];
	}
}

class NotEnoughElementsException extends Exception {
}

class SwapStack extends EStack {

	SwapStack(int size) {
		super(size);
	}

	/**
	 * taucht die beiden obersten Objekte auf dem Stack
	 * 
	 * @throws NotEnoughElementsException
	 *             wird geworfen, wenn sich keine zwei Objekte auf dem Stack
	 *             befinden
	 */
	public void swap() throws NotEnoughElementsException {
		Object wert1;
		Object wert2;
		try {
			wert1 = pop();
		} catch (IsEmptyException exc) {
			throw new NotEnoughElementsException();
		}

		try {
			wert2 = pop();
		} catch (IsEmptyException exc) {
			try {
				push(wert1);
			} catch (IsFullException exc2) {
				// kann nicht vorkommen
			}
			throw new NotEnoughElementsException();
		}

		try {
			push(wert1);
			push(wert2);
		} catch (IsFullException exc) {
			// kann nicht vorkommen
		}
	}
}

public class UE21Aufgabe3 {

	// Testprogramm (ohne Fehlerbehandlung)
	public static void main(String[] args) {
		final int anzahl = 1;
		try {
			SwapStack stack = new SwapStack(5);
			for (int i = 0; i < anzahl; i++) {
				stack.push(IO.readInt("Wert: "));
			}
			stack.swap();
			while (true) {
				System.out.println(stack.pop());
			}
		} catch (IsEmptyException exc) {
			// ok
		} catch (Exception exc) {
			exc.printStackTrace();
		}
	}

}
